@@ -7,7 +7,6 @@ try:  # pragma: no cover
 except ImportError:
     HTTPResponse = None
     WebSocketProtocol = None
-import six
 
 
 def create_route(app, engineio_server, engineio_endpoint):  # pragma: no cover
@@ -100,7 +99,7 @@ def make_response(status, headers, payload, environ):  # pragma: no cover
             content_type = h[1]
         else:
             headers_dict[h[0]] = h[1]
-    return HTTPResponse(body_bytes=payload, content_type=content_type,
+    return HTTPResponse(body=payload, content_type=content_type,
                         status=int(status.split()[0]), headers=headers_dict)
 
 
@@ -129,8 +128,8 @@ class WebSocket(object):  # pragma: no cover
 
     async def wait(self):
         data = await self._sock.recv()
-        if not isinstance(data, six.binary_type) and \
-                not isinstance(data, six.text_type):
+        if not isinstance(data, bytes) and \
+                not isinstance(data, str):
             raise IOError()
         return data
 
